import re
from typing import Optional
import requests
from bs4 import BeautifulSoup as soup

URL = "https://insta-stories.online"


class InstaViewer:
    def __init__(self, username, url=URL):
        self.url = url
        self.session = requests.Session()
        self.username = username
        self.user_id = None
        self.setup()

    def setup(self):
        self.session.headers.update({"user-agent": "respect"})

        # get homepage
        response = self.session.get(f"{URL}/{self.username}")
        html = soup(response.text, "html.parser")

        # set csrf token
        csrftoken = html.find("meta", {"name": "csrf-token"})["content"]
        self.session.headers.update({"x-csrf-token": csrftoken})

        # save user id
        self.user_id = re.search(r"app_insta\.user_id = '(\d+)'", response.text).group(1)

    def get_stories(self, format=None):
        response = self.session.post(f"{URL}/search", data={
            "getStories": "true", 
            "userId": self.user_id
        })
        response.raise_for_status()
        if format == "json":
            return response.text
        return response.json()

    def get_posts(self, format=None):
        response = self.session.post(f"{URL}/search", data={
            "getPosts": "true", 
            "userId": self.user_id
        })
        response.raise_for_status()
        if format == "json":
            return response.text
        return response.json()


# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['instaview']

package_data = \
{'': ['*']}

install_requires = \
['bs4>=0.0.1,<0.0.2', 'click>=8.0.1,<9.0.0', 'requests>=2.25.1,<3.0.0']

entry_points = \
{'console_scripts': ['instaview = src.instaview.cli:cli']}

setup_kwargs = {
    'name': 'instaview',
    'version': '0.1.2',
    'description': 'this package is just a scrapper of insta-stories.online',
    'long_description': None,
    'author': 'nowhere man',
    'author_email': 'man@nowhere.net',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



import click
from .scraper import InstaViewer


@click.command()
@click.argument("username")
def stories(username):
    ig = InstaViewer(username)
    data = ig.get_stories(format="json")
    print(data)

@click.command()
@click.argument("username")
def posts(username):
    ig = InstaViewer(username)
    data = ig.get_posts(format="json")
    print(data)


@click.group()
def cli():
    pass


if __name__ == "__main__":
    cli.add_command(stories)
    cli.add_command(posts)
    cli()